pub async fn execute_render_command(request: &RenderRequest) -> Result<()>Expand description
Execute a render using the compositions shipped with the standalone CLI.
pub async fn execute_render_command(request: &RenderRequest) -> Result<()>Execute a render using the compositions shipped with the standalone CLI.